require "defines"

-- script.on_event(defines.events.on_player_created, function(event)
-- end)

script.on_configuration_changed(function(data)
	for name, force in pairs(game.forces) do
		local technologies = force.technologies
		if data.mod_changes and data.mod_changes["Combat-variations"] and not data.mod_changes["Combat-variations"].old_version then
			if technologies["combat-robotics"].researched then
				force.maximum_following_robot_count = force.maximum_following_robot_count +1
			end
		end
		for name, tech in pairs(technologies) do
			if tech.researched and tech.effects then
				for i,effect in ipairs(tech.effects) do
					if effect.type == "unlock-recipe" and string.sub(effect.recipe, 1, 12) == "dispensable-" then
						force.recipes[effect.recipe].enabled = true
					end
				end
			end
		end
		if technologies["military-4"].researched then force.recipes["hand-cannon"].enabled = true end
	end
end)

function on_build_electric_fence(fence)
	fence.surface.create_entity{
		name = "electric-fence-turret",
		position = fence.position,
		force = fence.force
		}
	local pole = fence.surface.create_entity{
		name = "invisible-pole",
		position = fence.position,
		force = fence.force
		}
	pole.destructible = false
	fence.destructible = false
end

function on_removed_electric_fence(fence)
	local entities = fence.surface.find_entities({{ fence.position.x - 0.4, fence.position.y - 0.4 },{ fence.position.x + 0.4, fence.position.y + 0.4 }})
	for _,entity in pairs(entities) do
		if entity.name == "electric-fence" or entity.name == "invisible-pole" then
			entity.destroy()
		end
	end
end

function on_build_combat_inserter(inserter)
	inserter.insert({name = "solid-fuel", count = 1})	--25MJ in one solid fuel / 6.6W (reported) energy use = 43.8 real time days of energy.
	inserter.set_filter("basic-bullet-magazine", 1)
	inserter.set_filter("piercing-bullet-magazine", 2)
	inserter.set_filter("small-cannon-shell", 3)
	inserter.set_filter("small-explosive-cannon-shell", 4)
	inserter.operable = false
end


script.on_event(defines.events.on_built_entity, function(event)
	if event.created_entity.name == "electric-fence" then 
		on_build_electric_fence(event.created_entity)
	elseif event.created_entity.name == "combat-inserter" then 
		on_build_combat_inserter(event.created_entity)
	end
end)

script.on_event(defines.events.on_robot_built_entity, function(event)
	if event.created_entity.name == "electric-fence" then 
		on_build_electric_fence(event.created_entity)
	elseif event.created_entity.name == "combat-inserter" then 
		on_build_combat_inserter(event.created_entity)
	end
end)

script.on_event(defines.events.on_entity_died, function(event)
	if event.entity.name == "electric-fence-turret" then 
		on_removed_electric_fence(event.entity)
	end
end)

script.on_event(defines.events.on_preplayer_mined_item, function(event)
	if event.entity.name == "electric-fence-turret" then 
		on_removed_electric_fence(event.entity)
	end
end)

script.on_event(defines.events.on_robot_pre_mined, function(event)
	if event.entity.name == "electric-fence-turret" then 
		on_removed_electric_fence(event.entity)
	end
end)